@@ -271,6 +271,7 @@ extern char *catproc;
 extern char *components;
 extern char *context;
 extern char *current;
+extern char *defaulteditor;
 extern char *defaultfolder;
 extern char *digestcomps;
 extern char *distcomps;
@@ -308,7 +309,6 @@ extern char *rmmproc;
 extern char *sendproc;
 extern char *showmimeproc;
 extern char *showproc;
-extern char *sysed;
 extern char *usequence;
 extern char *version_num;
 extern char *version_str;
