@@ -152,7 +152,7 @@ int annotate (char *, char *, char *, int, int);
 int distout (char *, char *, char *);
 void replout (FILE *, char *, char *, struct msgs *, int,
 	int, char *, char *, char *);
-int sendsbr (char **, int, char *, struct stat *);
+int sendsbr (char **, int, char *, struct stat *, int);
 int what_now (char *, int, int, char *, char *,
 	int, struct msgs *, char *, int, char *);
 
