@@ -15,7 +15,7 @@ context_find (char *str)
 
     context_read();
     for (np = m_defs; np; np = np->n_next)
-	if (uleq (np->n_name, str))
+	if (!strcasecmp (np->n_name, str))
 	    return (np->n_field);
 
     return NULL;
