@@ -18,11 +18,11 @@ static void normalize (char *);
 
 
 /*
- * MAJOR HACK: See MHCHANGES for discussion
+ * Get new format string
  */
 
 char *
-new_fs (char *form, char *format, char *def)
+new_fs (char *form, char *format, char *default_fs)
 {
     struct stat st;
     register FILE *fp;
@@ -34,7 +34,7 @@ new_fs (char *form, char *format, char *def)
 	if ((fp = fopen (etcpath (form), "r")) == NULL)
 	    adios (form, "unable to open format file");
 
-	if (fstat (fileno (fp), &st) == NOTOK)
+	if (fstat (fileno (fp), &st) == -1)
 	    adios (form, "unable to stat format file");
 
 	if (!(formats = malloc ((size_t) st.st_size + 1)))
@@ -47,7 +47,7 @@ new_fs (char *form, char *format, char *def)
 
 	fclose (fp);
     } else {
-	formats = getcpy (format ? format : def);
+	formats = getcpy (format ? format : default_fs);
     }
 
     normalize (formats);
@@ -55,23 +55,40 @@ new_fs (char *form, char *format, char *def)
     return formats;
 }
 
-#define	grot(y,z) case y: *dp++ = z; break;
+
+/*
+ * Expand escapes in format strings
+ */
 
 static void
 normalize (char *cp)
 {
-    register char *dp;
+    char *dp;
 
     for (dp = cp; *cp; cp++) {
 	if (*cp != QUOTE) {
 	    *dp++ = *cp;
 	} else {
 	    switch (*++cp) {
-		grot ('b', '\b');
-		grot ('f', '\f');
-		grot ('n', '\n');
-		grot ('r', '\r');
-		grot ('t', '\t');
+		case 'b':
+		    *dp++ = '\b';
+		    break;
+
+		case 'f':
+		    *dp++ = '\f';
+		    break;
+
+		case 'n':
+		    *dp++ = '\n';
+		    break;
+
+		case 'r':
+		    *dp++ = '\r';
+		    break;
+
+		case 't':
+		    *dp++ = '\t';
+		    break;
 
 		case '\n':
 		    break;
@@ -84,5 +101,5 @@ normalize (char *cp)
 	    }
 	}
     }
-    *dp = 0;
+    *dp = '\0';
 }
