@@ -234,7 +234,7 @@ main (int argc, char **argv)
 	}
     }
 
-try_it_again: ;
+try_it_again:
     strcpy (drft, m_draft (dfolder, file, use, &isdf));
 
     /*
@@ -254,7 +254,7 @@ try_it_again: ;
 
 	if (stat (drft, &st) == NOTOK)
 	    adios (drft, "unable to stat");
-	printf ("Draft \"%s\" exists (%ld bytes).", drft, st.st_size);
+	printf ("Draft \"%s\" exists (%ld bytes).", drft, (long) st.st_size);
 	for (i = LISTDSW; i != YESW;) {
 	    if (!(argp = getans ("\nDisposition? ", isdf ? aqrunl : aqrul)))
 		done (1);
@@ -293,7 +293,7 @@ try_it_again: ;
     close (in);
     close (out);
 
-edit_it: ;
+edit_it:
     context_save ();	/* save the context file */
 
     if (nwhat)
