@@ -201,12 +201,12 @@ main (int argc, char **argv)
 	form = distcomps;
     }
 
-try_it_again: ;
+try_it_again:
     strcpy (drft, m_draft (dfolder, dmsg, NOUSE, &isdf));
 
     /* Check if draft already exists */
     if (stat (drft, &st) != NOTOK) {
-	printf ("Draft \"%s\" exists (%ld bytes).", drft, st.st_size);
+	printf ("Draft \"%s\" exists (%ld bytes).", drft, (long) st.st_size);
 	for (i = LISTDSW; i != YESW;) {
 	    if (!(argp = getans ("\nDisposition? ", isdf ? aqrnl : aqrl)))
 		done (1);
