@@ -344,20 +344,48 @@ mbx_copy (char *mailbox, int mbx_style, int md, int fd,
 	    for (j = 0; fgets (buffer, sizeof(buffer), fp) != NULL; j++) {
 
 		/*
-		 * Change the "Return-Path:" field (if in first line)
-		 * back to "From ".  We should probably add a check for
-		 * the "From " line, and build one if necessary.
+		 * Check the first line, and make some changes.
 		 */
-		if (j == 0 && !text && strncmp (buffer, "Return-Path:", 12) == 0) {
-		    char tmpbuffer[BUFSIZ];
-		    char *tp, *ep, *fp;
+		if (j == 0 && !text) {
+		    /*
+		     * Change the "Return-Path:" field (if in first line)
+		     * back to "From ".
+		     */
+		    if (!strncmp (buffer, "Return-Path:", 12)) {
+			char tmpbuffer[BUFSIZ];
+			char *tp, *ep, *fp;
 
-		    strcpy(tmpbuffer, buffer);
-		    ep = tmpbuffer + 13;
-		    if (!(fp = strchr(ep + 1, ' ')))
-			fp = strchr(ep + 1, '\n');
-		    tp = dctime(dlocaltimenow());
-		    sprintf (buffer, "From %.*s  %s", fp - ep, ep, tp);
+			strcpy(tmpbuffer, buffer);
+			ep = tmpbuffer + 13;
+			if (!(fp = strchr(ep + 1, ' ')))
+			    fp = strchr(ep + 1, '\n');
+			tp = dctime(dlocaltimenow());
+			sprintf (buffer, "From %.*s  %s", fp - ep, ep, tp);
+		    } else if (!strncmp (buffer, "X-Envelope-From:", 16)) {
+			/*
+			 * Change the "X-Envelope-From:" field
+			 * (if first line) back to "From ".
+			 */
+			char tmpbuffer[BUFSIZ];
+			char *ep;
+
+			strcpy(tmpbuffer, buffer);
+			ep = tmpbuffer + 17;
+			sprintf (buffer, "From %s", ep);
+		    } else if (strncmp (buffer, "From ", 5)) {
+			/*
+			 * If there is already a "From " line,
+			 * then leave it alone.  Else we add one.
+			 */
+			char tmpbuffer[BUFSIZ];
+			char *tp, *ep;
+
+			strcpy(tmpbuffer, buffer);
+			ep = "nobody@nowhere";
+			tp = dctime(dlocaltimenow());
+			sprintf (buffer, "From %s  %s", ep, tp);
+			strcat (buffer, tmpbuffer);
+		    }
 		}
 
 		/*
@@ -389,7 +417,7 @@ mbx_copy (char *mailbox, int mbx_style, int md, int fd,
 	    lseek (fd, (off_t) 0, SEEK_END);
 	    stop = lseek (md, (off_t) 0, SEEK_CUR);
 	    if (mapping)
-		map_write (mailbox, md, 0, (long)0, start, stop, pos, size, noisy);
+		map_write (mailbox, md, 0, (long) 0, start, stop, pos, size, noisy);
 
 	    return OK;
     }
