@@ -64,20 +64,19 @@ static struct swit switches[] = {
 
 extern int errno;
 
-static int fshort        = 0;	/* output only folder names                 */
-static int fcreat        = 0;	/* should we ask to create new folders?     */
-static int fpack         = 0;	/* are we packing the folder?               */
-static int fverb         = 0;	/* print actions taken while packing folder */
-static int fheader       = 0;	/* should we output a header?               */
-static int frecurse      = 0;	/* recurse through subfolders               */
-static int ftotal        = 0;	/* should we output the totals?             */
-static int all           = 0;	/* should we output all folders             */
+static int fshort   = 0;	/* output only folder names                 */
+static int fcreat   = 0;	/* should we ask to create new folders?     */
+static int fpack    = 0;	/* are we packing the folder?               */
+static int fverb    = 0;	/* print actions taken while packing folder */
+static int fheader  = 0;	/* should we output a header?               */
+static int frecurse = 0;	/* recurse through subfolders               */
+static int ftotal   = 0;	/* should we output the totals?             */
+static int all      = 0;	/* should we output all folders             */
 
-static int total_msgs    = 0;	/* total number of messages                 */
 static int total_folders = 0;	/* total number of folders                  */
 
-static int start    = 0;
-static int foldp    = 0;
+static int start = 0;
+static int foldp = 0;
 
 static char *nmhdir;
 static char *stack = "Folder-Stack";
@@ -506,9 +505,8 @@ get_folder_info (char *fold, char *msg)
 		context_save ();	/* save the context file     */
 	    }
 
+	    /* record info for this folder */
 	    if ((ftotal > 0) || !fshort) {
-		total_msgs += mp->nummsg;
-
 		fi[i].nummsg = mp->nummsg;
 		fi[i].curmsg = mp->curmsg;
 		fi[i].lowmsg = mp->lowmsg;
@@ -536,13 +534,14 @@ print_folders (void)
 {
     int i, len, hasempty = 0, curprinted;
     int maxlen = 0, maxnummsg = 0, maxlowmsg = 0;
-    int maxhghmsg = 0, maxcurmsg = 0;
+    int maxhghmsg = 0, maxcurmsg = 0, total_msgs = 0;
     int nummsgdigits, lowmsgdigits;
     int hghmsgdigits, curmsgdigits;
     char tmpname[BUFSIZ];
 
     /*
-     * compute width needed for printing various fields
+     * compute a few values needed to for
+     * printing various fields
      */
     for (i = 0; i < total_folders; i++) {
 	/* length of folder name */
@@ -554,6 +553,9 @@ print_folders (void)
 	if (fi[i].error)
 	    continue;
 
+	/* calculate total number of messages */
+	total_msgs += fi[i].nummsg;
+
 	/* maximum number of messages */
 	if (fi[i].nummsg > maxnummsg)
 	    maxnummsg = fi[i].nummsg;
