@@ -294,7 +294,7 @@ main (int argc, char **argv)
     if (file && (msgp || folder))
 	adios (NULL, "can't mix files and folders/msgs");
 
-try_it_again: ;
+try_it_again:
 
 #ifdef MHE
     strcpy (drft, buildsw ? m_maildir ("draft")
