@@ -203,7 +203,7 @@ main (int argc, char **argv)
      */
     if ((tmphost = getenv("MAILHOST")) != NULL)
 	pophost = tmphost;
-    else if ((po = hes_getmailhost(getusr())) != NULL &&
+    else if ((po = hes_getmailhost(getusername())) != NULL &&
 	     strcmp(po->po_type, "POP") == 0)
 	pophost = po->po_host;
 # endif /* HESIOD */
@@ -395,9 +395,9 @@ main (int argc, char **argv)
      */
     if (inc_type == INC_POP) {
 	if (user == NULL)
-	    user = getusr ();
+	    user = getusername ();
 	if (rpop > 0)
-	    pass = getusr ();
+	    pass = getusername ();
 	else
 	    ruserpass (host, &user, &pass);
 
