@@ -133,7 +133,7 @@ main (int argc, char **argv)
 	if (autof || gans (cp, anoyes))
 	    path = "Mail";
 	else {
-    query:  ;
+query:
 	    if (gans ("Do you want a path below your login directory? ",
 			anoyes)) {
 		printf ("What is the path?  %s/", mypath);
