@@ -65,10 +65,10 @@ static struct swit mhlswitches[] = {
     { "width columns", 0 },
 #define	SLEEPSW       12
     { "sleep seconds",  0 },
-#define	DASHSW        13
-    { "dashmunging", -4 },
-#define	NDASHSW       14
-    { "nodashmunging", -6 },
+#define	BITSTUFFSW    13
+    { "dashstuffing", -12 },	/* interface from forw */
+#define	NBITSTUFFSW   14
+    { "nodashstuffing", -14 },	/* interface from forw */
 #define VERSIONSW     15
     { "version", 0 },
 #define	HELPSW        16
@@ -76,7 +76,7 @@ static struct swit mhlswitches[] = {
 #define	FORW1SW       17
     { "forward", -7 },		/* interface from forw */
 #define	FORW2SW       18
-    { "forwall", -7 },		/*   .. */
+    { "forwall", -7 },		/* interface from forw */
 #define	DGSTSW        19
     { "digest list", -6 },
 #define VOLUMSW       20
@@ -193,12 +193,12 @@ static struct triple triples[] = {
 };
 
 
-static int bellflg = 0;
-static int clearflg = 0;
-static int dashflg = 1;
-static int dobody = 1;
-static int forwflg = 0;
-static int forwall = 0;
+static int bellflg   = 0;
+static int clearflg  = 0;
+static int dashstuff = 0;
+static int dobody    = 1;
+static int forwflg   = 0;
+static int forwall   = 0;
 
 static int sleepsw = NOTOK;
 
@@ -412,11 +412,11 @@ mhl (int argc, char **argv)
 		    clearflg = -1;/* XXX */
 		    continue;
 
-		case DASHSW: 
-		    dashflg++;
+		case BITSTUFFSW: 
+		    dashstuff = 1;	/* trinary logic */
 		    continue;
-		case NDASHSW: 
-		    dashflg = 0;
+		case NBITSTUFFSW: 
+		    dashstuff = -1;	/* trinary logic */
 		    continue;
 
 		case NBODYSW: 
@@ -678,8 +678,8 @@ evalvar (struct mcomp *c1)
 	return ptoi (name, &c1->c_cwidth);
     if (!strcasecmp (name, "length"))
 	return ptoi (name, &c1->c_length);
-    if (!strcasecmp (name, "nodashmunging"))
-	return (dashflg = 0);
+    if (!strcasecmp (name, "nodashstuffing"))
+	return (dashstuff = -1);
 
     for (ap = triples; ap->t_name; ap++)
 	if (!strcasecmp (ap->t_name, name)) {
@@ -847,7 +847,7 @@ mhlfile (FILE *fp, char *mname, int ofilen, int ofilec)
 		    }
 		    fflush (stdout);
 		    buf[0] = 0;
-		    read (fileno (stdout), buf, sizeof buf);
+		    read (fileno (stdout), buf, sizeof(buf));
 		}
 		if (strchr(buf, '\n')) {
 		    if ((global.c_flags & CLEARSCR))
@@ -871,13 +871,13 @@ mhlfile (FILE *fp, char *mname, int ofilen, int ofilec)
     }
 
     for (state = FLD;;) {
-	switch (state = m_getfld (state, name, buf, sizeof buf, fp)) {
+	switch (state = m_getfld (state, name, buf, sizeof(buf), fp)) {
 	    case FLD: 
 	    case FLDPLUS: 
 		for (ip = ignores; *ip; ip++)
 		    if (!strcasecmp (name, *ip)) {
 			while (state == FLDPLUS)
-			    state = m_getfld (state, name, buf, sizeof buf, fp);
+			    state = m_getfld (state, name, buf, sizeof(buf), fp);
 			break;
 		    }
 		if (*ip)
@@ -897,7 +897,7 @@ mhlfile (FILE *fp, char *mname, int ofilen, int ofilec)
 		if (c1 == NULL)
 		    c1 = add_queue (&msghd, &msgtl, name, buf, 0);
 		while (state == FLDPLUS) {
-		    state = m_getfld (state, name, buf, sizeof buf, fp);
+		    state = m_getfld (state, name, buf, sizeof(buf), fp);
 		    c1->c_text = add (buf, c1->c_text);
 		}
 		if (c2 == NULL)
@@ -927,13 +927,13 @@ mhlfile (FILE *fp, char *mname, int ofilen, int ofilec)
 			continue;
 		    }
 		    if (dobody && !strcasecmp (c1->c_name, "body")) {
-			if ((holder.c_text = malloc (sizeof buf)) == NULL)
+			if ((holder.c_text = malloc (sizeof(buf))) == NULL)
 			    adios (NULL, "unable to allocate buffer memory");
 			strcpy (holder.c_text, buf);
 			while (state == BODY) {
 			    putcomp (c1, &holder, BODYCOMP);
 			    state = m_getfld (state, name, holder.c_text,
-					sizeof buf, fp);
+					sizeof(buf), fp);
 			}
 			free (holder.c_text);
 			holder.c_text = NULL;
@@ -1045,7 +1045,7 @@ mcomp_format (struct mcomp *c1, struct mcomp *c2)
 
     (q = &pq)->pq_next = NULL;
     while ((cp = getname (ap))) {
-	if ((p = (struct pqpair *) calloc ((size_t) 1, sizeof *p)) == NULL)
+	if ((p = (struct pqpair *) calloc ((size_t) 1, sizeof(*p))) == NULL)
 	    adios (NULL, "unable to allocate pqpair memory");
 
 	if ((mp = getm (cp, NULL, 0, AD_NAME, error)) == NULL) {
@@ -1075,7 +1075,7 @@ mcomp_format (struct mcomp *c1, struct mcomp *c2)
 	if (cptr)
 	    cptr->c_text = p->pq_error;
 
-	fmt_scan (c1->c_fmt, buffer, sizeof buffer - 1, dat);
+	fmt_scan (c1->c_fmt, buffer, sizeof(buffer) - 1, dat);
 	if (*buffer) {
 	    if (c2->c_text)
 		c2->c_text = add (",\n", c2->c_text);
@@ -1101,7 +1101,7 @@ add_queue (struct mcomp **head, struct mcomp **tail, char *name, char *text, int
 {
     struct mcomp *c1;
 
-    if ((c1 = (struct mcomp *) calloc ((size_t) 1, sizeof *c1)) == NULL)
+    if ((c1 = (struct mcomp *) calloc ((size_t) 1, sizeof(*c1))) == NULL)
 	adios (NULL, "unable to allocate comp memory");
 
     c1->c_flags = flags & ~INIT;
@@ -1363,13 +1363,12 @@ putch (char ch)
 		putchar ('\007');
 	    fflush (stdout);
 	    buf[0] = 0;
-	    read (fileno (stdout), buf, sizeof buf);
+	    read (fileno (stdout), buf, sizeof(buf));
 	    if (strchr(buf, '\n')) {
 		if (global.c_flags & CLEARSCR)
 		    clear_screen ();
 		row = 0;
-	    }
-	    else {
+	    } else {
 		putchar ('\n');
 		row = global.c_length / 3;
 	    }
@@ -1389,8 +1388,14 @@ putch (char ch)
 	    break;
 
 	default: 
-	    if (column == 0 && forwflg && dashflg && ch == '-')
-		putchar ('-'), putchar (' ');
+	    /*
+	     * If we are forwarding this message, and the first
+	     * column contains a dash, then add a dash and a space.
+	     */
+	    if (column == 0 && forwflg && (dashstuff >= 0) && ch == '-') {
+		putchar ('-');
+		putchar (' ');
+	    }
 	    if (ch >= ' ')
 		column++;
 	    break;
@@ -1527,7 +1532,7 @@ bad_faceproc: ;
 	return NOTOK;
 
     result = sendto (sd, c1->c_text, strlen (c1->c_text), 0,
-		(struct sockaddr *) isock, sizeof *isock);
+		(struct sockaddr *) isock, sizeof(*isock));
 
     close (sd);
 
