@@ -113,7 +113,7 @@ main (int argc, char **argv)
 #endif
 
     uid = getuid ();
-    user = getusr();
+    user = getusername();
     invo_name = r1bindex (argv[0], '/');
     mts_init (invo_name);
 
@@ -142,7 +142,7 @@ main (int argc, char **argv)
 
 		case HELPSW: 
 		    snprintf (buf, 80, "%s [switches] [users ...]", invo_name);
-		    print_help (buf, switches);
+		    print_help (buf, switches, 1);
 		    done (1);
 		case VERSIONSW:
 		    print_version(invo_name);
@@ -363,9 +363,9 @@ remotemail (char *host, char *user, int rpop, int notifysw, int personal, int sn
     char *pass = NULL;
 
     if (user == NULL)
-	user = getusr ();
+	user = getusername ();
     if (rpop > 0)
-	pass = getusr ();
+	pass = getusername ();
     else
 	ruserpass (host, &user, &pass);
 
