@@ -1,6 +1,6 @@
 
 /*
- * pick.c -- select messages by content
+ * pick.c -- search for messages by content
  *
  * $Id$
  */
@@ -79,7 +79,7 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = context_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name))) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -103,7 +103,7 @@ main (int argc, char **argv)
 
 		case HELPSW: 
 		    sprintf (buf, "%s [+folder] [msgs] [switches]", invo_name);
-		    print_help (buf, switches);
+		    print_help (buf, switches, 1);
 		    listsw = 0;	/* HACK */
 		    done (1);
 		case VERSIONSW:
@@ -120,7 +120,7 @@ main (int argc, char **argv)
 		case BEFRSW: 
 		case SRCHSW: 
 		    vec[vecp++] = --cp;
-	    pattern: ;
+pattern:
 		    if (!(cp = *argp++))/* allow -xyz arguments */
 			adios (NULL, "missing argument to %s", argp[-2]);
 		    vec[vecp++] = cp;
@@ -178,8 +178,14 @@ main (int argc, char **argv)
 
     if (!context_find ("path"))
 	free (path ("./", TFOLDER));
+
+    /*
+     * If we didn't specify which messages to search,
+     * then searcht the whole folder.
+     */
     if (!msgp)
 	msgs[msgp++] = "all";
+
     if (!folder)
 	folder = getfolder (1);
     maildir = m_maildir (folder);
@@ -200,8 +206,13 @@ main (int argc, char **argv)
 	    done (1);
     seq_setprev (mp);	/* set the previous-sequence */
 
+    /*
+     * If we aren't saving the results to a sequence,
+     * we need to list the results.
+     */
     if (seqp == 0)
 	listsw++;
+
     if (publicsw == 1 && is_readonly(mp))
 	adios (NULL, "folder %s is read-only, so -public not allowed", folder);
 
