@@ -202,9 +202,9 @@ main (int argc, char **argv)
 #endif
 
     if (user == NULL)
-	user = getusr ();
+	user = getusername ();
     if (rpop > 0)
-	pass = getusr ();
+	pass = getusername ();
     else {
 	setuid (getuid ());
 	ruserpass (host, &user, &pass);
