@@ -331,7 +331,7 @@ main (int argc, char **argv)
     if (file && (msg || folder))
 	adios (NULL, "can't mix files and folders/msgs");
 
-try_it_again:;
+try_it_again:
 
 #ifdef MHE
     strcpy (drft, buildsw ? m_maildir ("reply")
@@ -345,7 +345,7 @@ try_it_again:;
     /* Check if a draft exists */
     if (stat (drft, &st) != NOTOK) {
 #endif /* MHE */
-	printf ("Draft \"%s\" exists (%ld bytes).", drft, st.st_size);
+	printf ("Draft \"%s\" exists (%ld bytes).", drft, (long) st.st_size);
 	for (i = LISTDSW; i != YESW;) {
 	    if (!(argp = getans ("\nDisposition? ", isdf ? aqrnl : aqrl)))
 		done (1);
