@@ -154,7 +154,7 @@ replout (FILE *inb, char *msg, char *drft, struct msgs *mp, int outputlinelen,
 		 */
 		if ((cptr = wantcomp[CHASH(name)]))
 		    do {
-			if (uleq(name, cptr->c_name)) {
+			if (!strcasecmp(name, cptr->c_name)) {
 			    char_read += msg_count;
 			    if (! cptr->c_text) {
 				cptr->c_text = tmpbuf;
@@ -202,7 +202,7 @@ replout (FILE *inb, char *msg, char *drft, struct msgs *mp, int outputlinelen,
 finished:
 
     /*
-     * if there's a "subject" component, strip any "Re:"s off it
+     * if there's a "Subject" component, strip any "Re:"s off it
      */
     FINDCOMP (cptr, "subject")
     if (cptr && (cp = cptr->c_text)) {
@@ -243,14 +243,10 @@ finished:
      */
     if (filter) {
 	replfilter (inb, out, filter);
-    }
-#ifdef MIME
-    else {
-	if (mime && mp)
+    } else if (mime && mp) {
 	    fprintf (out, "#forw [original message] +%s %s\n",
 		     mp->foldpath, m_name (mp->lowsel));
     }
-#endif /* MIME */
 
     if (ferror (out))
 	adios (drft, "error writing");
@@ -386,8 +382,8 @@ insert (struct mailname *np)
 	return 0;
 
     for (mp = &mq; mp->m_next; mp = mp->m_next) {
-	if (uleq (np->m_host, mp->m_next->m_host)
-		&& uleq (np->m_mbox, mp->m_next->m_mbox))
+	if (!strcasecmp (np->m_host, mp->m_next->m_host)
+		&& !strcasecmp (np->m_mbox, mp->m_next->m_mbox))
 	    return 0;
     }
     if (!ccme && ismymbox (np))
