@@ -72,7 +72,7 @@ main (int argc, char **argv)
 #endif
     invo_name = r1bindex (argv[0], '/');
     mts_init (invo_name);
-    if ((cp = context_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name))) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -82,7 +82,7 @@ main (int argc, char **argv)
     argp = arguments;
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, switches);
@@ -92,7 +92,7 @@ main (int argc, char **argv)
 
 		case HELPSW: 
 		    sprintf (buf, "%s [+folder] [msgs] [switches]", invo_name);
-		    print_help (buf, switches);
+		    print_help (buf, switches, 1);
 		    done (1);
 		case VERSIONSW:
 		    print_version(invo_name);
@@ -142,6 +142,7 @@ main (int argc, char **argv)
 			file = path (cp, TFILE);
 		    continue;
 	    }
+	}
 	if (*cp == '+' || *cp == '@') {
 	    if (folder)
 		adios (NULL, "only one folder at a time!");
@@ -251,7 +252,7 @@ main (int argc, char **argv)
 
     for (msgnum = revflag ? mp->hghsel : mp->lowsel;
 	 (revflag ? msgnum >= mp->lowsel : msgnum <= mp->hghsel);
-	 msgnum += revflag ? (-1) : 1) {
+	 msgnum += (revflag ? -1 : 1)) {
 	if (is_selected(mp, msgnum)) {
 	    if ((in = fopen (cp = m_name (msgnum), "r")) == NULL) {
 #if 0
@@ -271,7 +272,10 @@ main (int argc, char **argv)
 	    }
 #endif /* JLR */
 
-	    /* Check if message is unseen */
+	    /*
+	     * Check if message is in any sequence given
+	     * by Unseen-Sequence profile entry.
+	     */
 	    unseen = 0;
 	    for (i = 0; i < num_unseen_seq; i++) {
 		if (in_sequence(mp, seqnum[i], msgnum)) {
