@@ -8,6 +8,15 @@
 #include <h/mh.h>
 
 
+/*
+ * This routine is used by comp, repl, forw, and dist to exec
+ * the "whatnowproc".  It first sets up all the environment
+ * variables that the "whatnowproc" will need to check, and
+ * then execs the command.  As an optimization, if the
+ * "whatnowproc" is the nmh command "whatnow" (typical case),
+ * it will call this routine directly without exec'ing it.
+ */
+
 int
 what_now (char *ed, int nedit, int use, char *file, char *altmsg, int dist,
           struct msgs *mp, char *text, int inplace, char *cwd)
@@ -39,10 +48,12 @@ what_now (char *ed, int nedit, int use, char *file, char *altmsg, int dist,
 	m_putenv ("editalt", bp);
     sprintf (buffer, "%d", dist);
     m_putenv ("mhdist", buffer);
-    if (nedit)
+    if (nedit) {
 	unputenv ("mheditor");
-    else
-	m_putenv ("mheditor", ed ? ed : (ed = context_find ("editor")) ? ed : sysed);
+    } else {
+	m_putenv ("mheditor", ed ? ed : (ed = context_find ("editor"))
+	    ? ed : defaulteditor);
+    }
     sprintf (buffer, "%d", use);
     m_putenv ("mhuse", buffer);
 
@@ -52,7 +63,7 @@ what_now (char *ed, int nedit, int use, char *file, char *altmsg, int dist,
     if (text && mp && !is_readonly(mp)) {
 	found = 0;
 	bp = buffer;
-	for (msgnum = mp->lowmsg; msgnum <= mp->hghmsg; msgnum++)
+	for (msgnum = mp->lowmsg; msgnum <= mp->hghmsg; msgnum++) {
 	    if (is_selected(mp, msgnum)) {
 		sprintf (bp, "%s%s", found ? " " : "", m_name (msgnum));
 		bp += strlen (bp);
@@ -65,6 +76,7 @@ what_now (char *ed, int nedit, int use, char *file, char *altmsg, int dist,
 		msgnum = k + 1;
 		found++;
 	    }
+	}
 	if (found) {
 	    m_putenv ("mhmessages", buffer);
 	    m_putenv ("mhannotate", text);
@@ -80,9 +92,8 @@ what_now (char *ed, int nedit, int use, char *file, char *altmsg, int dist,
 	chdir (cwd);
 
     /*
-     * If the "whatnowproc" is the nmh command
-     * "whatnow", we run it internally, rather
-     * than exec'ing it.
+     * If the "whatnowproc" is the nmh command "whatnow",
+     * we run it internally, rather than exec'ing it.
      */
     if (strcmp (vec[0], "whatnow") == 0) {
 	WhatNow (vecp, vec);
