@@ -34,24 +34,26 @@ static struct swit whatnowswitches[] = {
  * Options at the "whatnow" prompt
  */
 static struct swit aleqs[] = {
-#define	DISPSW                         0
-    { "display [<switches>]", 0 },
-#define BUILDMIMESW                    1
-    { "mime [<switches>]", 0 },
-#define	EDITSW                         2
+#define	EDITSW                         0
     { "edit [<editor> <switches>]", 0 },
-#define	LISTSW                         3
-    { "list [<switches>]", 0 },
-#define	PUSHSW                         4
-    { "push [<switches>]", 0 },
-#define	QUITSW                         5
-    { "quit [-delete]", 0 },
-#define	REFILEOPT                      6
+#define	REFILEOPT                      1
     { "refile [<switches>] +folder", 0 },
-#define	SENDSW                         7
+#define BUILDMIMESW                    2
+    { "mime [<switches>]", 0 },
+#define	DISPSW                         3
+    { "display [<switches>]", 0 },
+#define	LISTSW                         4
+    { "list [<switches>]", 0 },
+#define	SENDSW                         5
     { "send [<switches>]", 0 },
-#define	WHOMSW                         8
+#define	PUSHSW                         6
+    { "push [<switches>]", 0 },
+#define	WHOMSW                         7
     { "whom [<switches>]", 0 },
+#define	QUITSW                         8
+    { "quit [-delete]", 0 },
+#define DELETESW                       9
+    { "delete", 0 },
     { NULL, 0 }
 };
 
@@ -60,12 +62,14 @@ static char *myprompt = "\nWhat now? ";
 /*
  * static prototypes
  */
-static int editfile (char **, char **, char *, int, struct msgs *, char *, char *);
+static int editfile (char **, char **, char *, int, struct msgs *,
+	char *, char *, int);
 static int sendfile (char **, char *, int);
 static void sendit (char *, char **, char *, int);
-static int build_mime (char **, char *);
-static int whomfile (char **, char *);
+static int buildfile (char **, char *);
 static int check_draft (char *);
+static int whomfile (char **, char *);
+static int removefile (char *);
 
 #ifdef HAVE_LSTAT
 static int copyf (char *, char *);
@@ -83,7 +87,7 @@ WhatNow (int argc, char **argv)
     struct stat st;
 
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = context_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name))) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -92,7 +96,6 @@ WhatNow (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-
     while ((cp = *argp++)) {
 	if (*cp == '-') {
 	    switch (smatch (++cp, whatnowswitches)) {
@@ -152,12 +155,19 @@ WhatNow (int argc, char **argv)
 
     if ((drft == NULL && (drft = getenv ("mhdraft")) == NULL) || *drft == 0)
 	drft = getcpy (m_draft (dfolder, dmsg, 1, &isdf));
+
     msgnam = (cp = getenv ("mhaltmsg")) && *cp ? getcpy (cp) : NULL;
-    if (ed == NULL && ((ed = getenv ("mheditor")) == NULL || *ed == 0))
-	ed = NULL, nedit++;
+
     if ((cp = getenv ("mhuse")) && *cp)
 	use = atoi (cp);
-    if (!nedit && editfile (&ed, NULL, drft, use, NULL, msgnam, NULL) < 0)
+
+    if (ed == NULL && ((ed = getenv ("mheditor")) == NULL || *ed == 0)) {
+	ed = NULL;
+	nedit++;
+    }
+
+    /* start editing the draft, unless -noedit was given */
+    if (!nedit && editfile (&ed, NULL, drft, use, NULL, msgnam, NULL, 1) < 0)
 	done (1);
 
     sprintf (prompt, myprompt, invo_name);
@@ -177,16 +187,14 @@ WhatNow (int argc, char **argv)
 
 	case BUILDMIMESW:
 	    /* Translate MIME composition file */
-	    ++argp;
-	    if (build_mime(argp, drft) == NOTOK)
-		done (1);
+	    buildfile (++argp, drft);
 	    break;
 
 	case EDITSW:
 	    /* Call an editor on the draft file */
 	    if (*++argp)
 		ed = *argp++;
-	    if (editfile (&ed, argp, drft, NOUSE, NULL, msgnam, NULL) == NOTOK)
+	    if (editfile (&ed, argp, drft, NOUSE, NULL, msgnam, NULL, 1) == NOTOK)
 		done (1);
 	    break;
 
@@ -201,13 +209,19 @@ WhatNow (int argc, char **argv)
 	    break;
 
 	case QUITSW:
+	    /* Quit, and possibly delete the draft */
 	    if (*++argp && (*argp[0] == 'd' ||
-			    ((*argp)[0] == '-' && (*argp)[1] == 'd'))) {
-		if (unlink (drft) == NOTOK)
-		    adios (drft, "unable to unlink");
-	    } else
+		((*argp)[0] == '-' && (*argp)[1] == 'd'))) {
+		removefile (drft);
+	    } else {
 		if (stat (drft, &st) != NOTOK)
 		    advise (NULL, "draft left on %s", drft);
+	    }
+	    done (1);
+
+	case DELETESW:
+	    /* Delete draft and exit */
+	    removefile (drft);
 	    done (1);
 
 	case PUSHSW:
@@ -228,6 +242,7 @@ WhatNow (int argc, char **argv)
 	    break;
 
 	default: 
+	    /* Unknown command */
 	    advise (NULL, "say what?");
 	    break;
 	}
@@ -239,19 +254,17 @@ WhatNow (int argc, char **argv)
  * EDIT
  */
 
-static int  reedit = 0;
-static char *edsave = NULL;
+static int  reedit = 0;		/* have we been here before?     */
+static char *edsave = NULL;	/* the editor we used previously */
 
 
 static int
-editfile (char **ed, char **arg, char *file, int use,
-          struct msgs *mp, char *altmsg, char *cwd)
+editfile (char **ed, char **arg, char *file, int use, struct msgs *mp,
+	  char *altmsg, char *cwd, int save_editor)
 {
-    int pid, status;
-    int vecp;
-    char *cp;
+    int pid, status, vecp;
     char altpath[BUFSIZ], linkpath[BUFSIZ];
-    char *vec[MAXARGS];
+    char *cp, *vec[MAXARGS];
     struct stat st;
 
 #ifdef HAVE_LSTAT
@@ -261,19 +274,22 @@ editfile (char **ed, char **arg, char *file, int use,
 #endif
 #endif /* HAVE_LSTAT */
 
-    /* set initial editor */
-    if (!reedit) {
-	if (*ed == NULL && (*ed = context_find ("editor")) == NULL)
-	    *ed = sysed;
-    } else {
-	if (!*ed) {		/* no explicit editor */
-	    *ed = edsave;
+    /* Was there a previous edit session? */
+    if (reedit) {
+	if (!*ed) {		/* no explicit editor      */
+	    *ed = edsave;	/* so use the previous one */
 	    if ((cp = r1bindex (*ed, '/')) == NULL)
 		cp = *ed;
+
+	    /* unless we've specified it via "editor-next" */
 	    cp = concat (cp, "-next", NULL);
 	    if ((cp = context_find (cp)) != NULL)
 		*ed = cp;
 	}
+    } else {
+	/* set initial editor */
+	if (*ed == NULL && (*ed = context_find ("editor")) == NULL)
+	    *ed = defaulteditor;
     }
 
     if (altmsg) {
@@ -389,7 +405,10 @@ editfile (char **ed, char **arg, char *file, int use,
 #endif /* HAVE_LSTAT */
     }
 
-    edsave = getcpy (*ed);
+    /* normally, we remember which editor we used */
+    if (save_editor)
+	edsave = getcpy (*ed);
+
     *ed = NULL;
     if (altmsg)
 	unlink (linkpath);
@@ -443,14 +462,14 @@ sendfile (char **arg, char *file, int pushsw)
 	    && (!strcmp (cp, "1"))
 	    && !getenv ("NOMHNPROC")
 	    && check_draft (file)
-	    && (build_mime (NULL, file) == NOTOK))
+	    && (buildfile (NULL, file) == NOTOK))
 	return 0;
 
     /* For backwards compatibility */
     if ((cp = context_find ("automhnproc"))
 	    && !getenv ("NOMHNPROC")
 	    && check_draft (file)
-	    && (i = editfile (&cp, NULL, file, NOUSE, NULL, NULL, NULL)))
+	    && (i = editfile (&cp, NULL, file, NOUSE, NULL, NULL, NULL, 0)))
 	return 0;
 
     /*
@@ -501,7 +520,7 @@ sendfile (char **arg, char *file, int pushsw)
  */
 
 static int
-build_mime (char **argp, char *file)
+buildfile (char **argp, char *file)
 {
     int i;
     char **args, *ed;
@@ -530,13 +549,10 @@ build_mime (char **argp, char *file)
 	args[i++] = *argp++;
     args[i] = NULL;
 
-    i = editfile (&ed, args, file, NOUSE, NULL, NULL, NULL);
+    i = editfile (&ed, args, file, NOUSE, NULL, NULL, NULL, 0);
     free (args);
 
-    if (i)
-	return NOTOK;
-    else
-	return OK;
+    return (i ? NOTOK : OK);
 }
 
 
@@ -878,7 +894,7 @@ sendit (char *sp, char **arg, char *file, int pushed)
     vec[0] = r1bindex (postproc, '/');
     closefds (3);
 
-    if (sendsbr (vec, vecp, file, &st) == OK)
+    if (sendsbr (vec, vecp, file, &st, 1) == OK)
 	done (0);
 }
 
@@ -919,3 +935,17 @@ whomfile (char **arg, char *file)
 	    return (pidwait (pid, NOTOK) & 0377 ? 1 : 0);
     }
 }
+
+
+/*
+ * Remove the draft file
+ */
+
+static int
+removefile (char *drft)
+{
+    if (unlink (drft) == NOTOK)
+	adios (drft, "unable to unlink");
+
+    return OK;
+}
