@@ -15,7 +15,11 @@
 #define YYLMAX 256
 
 struct yysvf { 
+#ifndef hpux
 	struct yywork *yystoff;
+#else	/* hpux */
+	int yystoff;
+#endif	/* hpux */
 	struct yysvf *yyother;
 	int *yystops;
 };
@@ -82,11 +86,19 @@ lex_string (char **strptr, int start_cond)
 			fprintf(stderr,"%d ",statenum - 1);
 		}
 #endif
+#ifndef hpux
 		tran = state->yystoff;
+#else	/* hpux */
+		tran = &yycrank[state->yystoff];
+#endif	/* hpux */
 		if(tran == yycrank)
 			/* may not be any transitions */
 			if (state->yyother == 0 ||
+#ifndef hpux
 			    state->yyother->yystoff == yycrank)
+#else	/* hpux */
+			    state->yyother->yystoff == 0)
+#endif	/* hpux */
 				break;
 
 #ifdef ONECASE
@@ -102,7 +114,11 @@ lex_string (char **strptr, int start_cond)
 		}
 #endif
 tryagain:
+#ifndef hpux
 		if ( tran > yycrank){
+#else	/* hpux */
+		if ( (int)tran > (int)yycrank){
+#endif	/* hpux */
 			tran += ch;
 			if (tran->verify == statenum){
 				if ((statenum = tran->advance) == 0){
@@ -115,7 +131,11 @@ tryagain:
 				goto contin;
 			}
 
+#ifndef hpux
 		} else if(tran < yycrank) {
+#else	/* hpux */
+		} else if( (int)tran < (int)yycrank) {
+#endif	/* hpux */
 			tran = yycrank+(yycrank-tran) + ch;
 #ifdef LEXDEBUG
 			if (debug) {
@@ -150,7 +170,11 @@ tryagain:
 			}
 		}
 		if ((state = state->yyother) &&
+#ifndef hpux
 		    (tran = state->yystoff) != yycrank){
+#else	/* hpux */
+		    (tran = &yycrank[state->yystoff]) != yycrank){
+#endif	/* hpux */
 			statenum = state - yysvec;
 #ifdef LEXDEBUG
 			if (debug) {
